# chromo-map
Extend Functionality to Color Map Objects

[![PyPI version](https://badge.fury.io/py/chromo-map.svg)](https://badge.fury.io/py/chromo-map)

[![Build Status](https://github.com/pirsquared/chromo-map/actions/workflows/publish-pypi-pages.yml/badge.svg)](https://github.com/pirsquared/chromo-map/actions)

## Overview

`chromo-map` is a Python package that extends the functionality of color map objects. It provides a simple interface to create custom color maps, and to manipulate existing color maps. The package is built on top of the `matplotlib` library, and is designed to be easy to use and flexible.

## Documentation

Full documentation is available at [chromo-map](https://pirsquared.github.io/chromo-map/).

## Installation

`pip install chromo-map`
